function error = drumFreqEqError(omega,k)

% Function used to find the nondimensionalized natural
% frequencies omega of a drum whose membrane is flexibly
% attached with nondimensional flexibility k.
%
% Input:
%    omega: The nondimensional natural frequency to
%           examine, in radians.
%    k:     The nondimensional flexibility of the
%           membrane attachment
%
% Output:
%    error: If error is zero, then the frequency is a
%           valid one for that value of k.  Note that the
%           membrane can vibrate with infinitely many
%           frequencies (theoretically at least)
%
% Advanced analysis taught in Analysis in Mechanical
% Engineering II shows that the equation the frequencies
% must satisfy is:
%              k omega J1(omega) = J0(omega)
% where J0 and J1 are Bessel functions of the first kind.
% So if the frequency is not right, the error in the
% equation (difference between the right and left hand
% sides) is:
%          error = J0(omega) - k omega J1(omega)

% Evaluate the error:
error = besselj(0,omega) - k*omega.*besselj(1,omega);
% Do not forget the semi-colon and . before *.

end

